Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Analysis ¶
type Analysis struct {
Item *item.Item
Days int
AveragePrice float64
AverageVolume int64
AverageSpread float64
AverageHigh float64
AverageLow float64
AverageProfitMargin float64
AverageOffset float64
ISKVol float64
// Hypothetical profit if you were to execute every order of the day
LPDP float64
// Orders that have been updated in the last 24h
Flippers int
// Aggregation of factors based on weights
Score int
}
type Analyzer ¶
type Analyzer struct {
// contains filtered or unexported fields
}
func NewAnalyzer ¶
func (*Analyzer) PassesFilters ¶
Click to show internal directories.
Click to hide internal directories.